@@ -6,7 +6,7 @@ ARCHIVEOS_DOMAIN='scupper.club'
 ARCHIVEOS_BASEDN='dc=scupper,dc=club'
 
 def list_admins():
-    ldap_url = 'ldap://' + ARCHIVEOS_ROOT
+    ldap_url = 'ldap://' + ARCHIVEOS_DOMAIN
     connect = ldap.initialize(ldap_url)
     connect.simple_bind_s()
     r = connect.search_s(ARCHIVEOS_BASEDN, ldap.SCOPE_SUBTREE, 'uid=*', displayName)
